%  CNT_MOGICA.M
%
%  cnt_mogica( datafile, initA, iter, nsave, diag_qs ) continues the
%  simulations started with RUN_MOGICA. The trained model is loaded
%  from the file created by RUN_MOGICA.
%
%  Examples:
%    cnt_mogica( 'sg_1_0', 'PCA', 2000, 100, 0 )
%
function cnt_mogica( datafile, initA, iter, nsave, diag_qs )

if nargin < 5 | isempty(diag_qs)
    diag_qs = 0;
end

if diag_qs
    netfile = [ package_dir '/RESULTS/Diag_Qs/mog__' datafile '__' initA ];
else
    netfile = [ package_dir '/RESULTS/Full_Qs/mog__' datafile '__' initA ];
end


load( netfile, 'net', 'nit', 'CF' )
load( [ package_dir '/DATA/' datafile ], 'x' )
x = x';
status.iter = nit(end);
status.CF = CF;
status.diag_qs = diag_qs;

nnets = length(net);
itercomplete = nit(end);
for i = 1:ceil( (iter-itercomplete)/nsave )
    
    if itercomplete + i*nsave > iter
        nit(nnets+i) = iter;
    else
        nit(nnets+i) = itercomplete + i*nsave;
    end
    [ net{nnets+i}, status ] = mogica( x, nit(nnets+i),...
                                      net{nnets+i-1}, status );
    CF = status.CF;
    
    save( netfile, 'net', 'nit', '-append' )

end

disp( [ 'The results written to ' netfile ] )

